---
title: 워드프레스 플러그인
description: 워드프레스 플러그인을 통해 포트원을 사용하는 방법을 안내합니다.
targetVersions:
  - v1
---

우커머스 플러그인을 통해 워드프레스에서 포트원을 사용할 수 있습니다.

[우커머스 플러그인](https://developers.portone.io/opi/ko/extra/plugins/wordpress/woocommerce/readme)
